@@ -366,6 +366,6 @@ def argument_inspector(arg, lib=None, no_of_arguments=2, p=False, print_width=12
         return rtrnd_dct
 
 
-inspection_arguments = [1, 1.2, 'abc', '1', '1.2', '1/2', {1, 2, 3}, {'a': 1, 'b': 2}, (1, 2, 3), [1, 2, 3],
+inspection_arguments = [1, 0, 1.2, 'abc', '1', '0', '1.2', '1/2', {1, 2, 3}, {'a': 1, 'b': 2}, (1, 2, 3), [1, 2, 3],
                         {'a', 'b', 'c'}, ('a', 'b', 'c'), ['a', 'b', 'c'], 1 + 2j, b'2', b'a', bytearray(1),
                         frozenset({1, 2, 3}), frozenset({'a', 'b', 'c'})]
